/*
 * CTU Open Contest 2012
 *
 * Sample solution: Cockchafer
 * Author: Zdenek Dvorak
 */


#include <list>
#include <map>
#include <cstdio>
#include <cmath>
using namespace std;
 
struct point
{
  int x, y, z;
};
 
bool operator==(const point &a, const point &b)
{
  return a.x == b.x && a.y == b.y && a.z == b.z;
}
bool operator!=(const point &a, const point &b)
{
  return !(a == b);
}
bool operator<(const point &a, const point &b)
{
  if (a.x < b.x)
    return true;
  if (a.x > b.x)
    return false;
  if (a.y < b.y)
    return true;
  if (a.y > b.y)
    return false;
  return a.z < b.z;
}
 
static int n, s, t;
static point begin, end;
 
struct trans
{
  int to_edge;
  double dist;
 
  trans (int toe, double d)
    {
      to_edge = toe;
      dist = d;
    }
};
 
struct edir
{
  list<trans> nbrs;
  double adist;
  bool dist_final;
  bool to_end;
};
 
static edir graph[2000];
 
struct segment
{
  point other_end;
  double len;
  int edir_id;
 
  segment(const point &oe, double l, int i)
    {
      other_end = oe;
      len = l;
      edir_id = i;
    }
};
 
struct point_record
{
  list<segment> incoming, outgoing;
};
 
static map<point,point_record> points;
 
static void
read_point (point &p)
{
  scanf ("%d%d%d", &p.x, &p.y, &p.z);
}
 
static double
pdistance (const point &p1, const point &p2)
{
  int dx = p1.x - p2.x;
  int dy = p1.y - p2.y;
  int dz = p1.z - p2.z;
  return sqrt (dx * dx + dy * dy + dz * dz);
}
 
static void
add_nbr (int fidx, int tidx, double len)
{
  graph[fidx].nbrs.push_back (trans (tidx, len));
}
 
static double
angle (const point &p1, const point &p2, const point &p3)
{
  int ux = p2.x - p1.x;
  int uy = p2.y - p1.y;
  int uz = p2.z - p1.z;
  int vx = p3.x - p2.x;
  int vy = p3.y - p2.y;
  int vz = p3.z - p2.z;
  double l1 = pdistance (p1, p2);
  double l2 = pdistance (p2, p3);
  double sprod = ux * vx + uy * vy + uz * vz;
 
  return 180 * acos (sprod / l1 / l2) / M_PI;
}
 
static void
add_edge (int eidx, const point &p1, const point &p2)
{
  double len = pdistance (p1, p2) / s;
 
  if (p1 == begin)
    graph[eidx].adist = len;
  else
    graph[eidx].adist = INFINITY;
 
  graph[eidx].dist_final = false;
  graph[eidx].to_end = (p2 == end);
 
  point_record &p1i = points[p1];
  point_record &p2i = points[p2];
 
  graph[eidx].nbrs.clear ();
  list<segment>::iterator li;
  for (li = p2i.outgoing.begin (); li != p2i.outgoing.end (); ++li)
    if (li->other_end != p1)
      add_nbr (eidx, li->edir_id, li->len + angle (p1, p2, li->other_end) / t);
  for (li = p1i.incoming.begin (); li != p1i.incoming.end (); ++li)
    if (li->other_end != p2)
      add_nbr (li->edir_id, eidx, len + angle (li->other_end, p1, p2) / t);
 
  p1i.outgoing.push_back(segment(p2, len, eidx));
  p2i.incoming.push_back(segment(p1, len, eidx));
}
 
static double
dijkstra (void)
{
  while (1)
    {
      double mind = INFINITY;
      int bestv = 0;
      for (int v = 0; v < n; v++)
	if (!graph[v].dist_final && graph[v].adist < mind)
	  {
	    mind = graph[v].adist;
	    bestv = v;
	  }
 
      if (graph[bestv].to_end)
	return mind;
      graph[bestv].dist_final = true;
 
      for (list<trans>::iterator li = graph[bestv].nbrs.begin (); li != graph[bestv].nbrs.end (); ++li)
	{
	  int nv = li->to_edge;
	  double nd = mind + li->dist;
	  if (nd < graph[nv].adist)
	    graph[nv].adist = nd;
	}
    }
}
 
int main(void)
{
  while (scanf ("%d%d%d", &n, &s, &t) == 3)
    {
      points.clear ();
      read_point (begin);
      read_point (end);
      n *= 2;
 
      for (int i = 0; i < n; i += 2)
	{
	  point p1, p2;
	  read_point (p1);
	  read_point (p2);
	  add_edge (i, p1, p2);
	  add_edge (i + 1, p2, p1);
	}
 
      if (begin == end)
	printf ("0.0000\n");
      else
	printf ("%.4f\n", dijkstra ());
    }
 
  return 0;
}

